/*************************************************************************//**
 *   @file   app_config.h
 *   @brief  Configuration file of AD7124 firmware example program
******************************************************************************
* Copyright (c) 2020 Analog Devices, Inc.
*
* All rights reserved.
*
* This software is proprietary to Analog Devices, Inc. and its licensors.
* By using this software you agree to the terms of the associated
* Analog Devices Software License Agreement.
*****************************************************************************/

#ifndef _APP_CONFIG_H_
#define _APP_CONFIG_H_

#include <stdint.h>
#include <PinNames.h>

//#define  ARDUINO

/**
  The ADI SDP_K1 can be used with both arduino headers
  or the 120-pin SDP connector found on ADI evaluation
  boards. The default is the SDP connector.

  Uncomment the ARDUINO #define above to enable the ARDUINO connector
*/

// Pin mapping of AD7124 with SDP-K1/Arduino (reference: PinNames.h)
#ifdef ARDUINO
#define I2C_SCL		D15		// I2C_SCL
#define I2C_SDA		D14		// I2C_SDA

#define SPI_SS		D10		// SPI_CS
#define SPI_MISO	D11		// SPI_MOSI
#define SPI_MOSI	D12		// SPI_MISO
#define SPI_SCK		D13		// SPI_SCK
#else
#define I2C_SCL		SDP_I2C_SCL		// PH_7
#define I2C_SDA		SDP_I2C_SDA		// PC_9

#define SPI_SS_A	SDP_SPI_CS_A	// PB_9
#define SPI_SS_B	SDP_SPI_CS_B	// PC_6
#define SPI_SS_C	SDP_SPI_CS_C	// PC_7
#define SPI_MISO	SDP_SPI_MISO	// PF_8
#define SPI_MOSI	SDP_SPI_MOSI	// PF_9
#define SPI_SCK		SDP_SPI_SCK		// PH_6
#endif

// Common pin mappings
#define LED_GREEN	LED3	// PK_5

#endif //_APP_CONFIG_H_
